@@ -44,8 +44,8 @@ class CallRun(object):
         self._command = command
 
     def __call__(self, config, template_path, output):
-        LOGGER.debug('running CallRun("%s")', self._command )
-        return subprocess.call(self._command)
+        LOGGER.debug('running CallRun("%s")', self._command)
+        return subprocess.check_call(self._command, shell=True, cwd=output)
 
 
 class CallCopy(object):
@@ -54,25 +54,24 @@ class CallCopy(object):
 
     def __call__(self, config, template_path, output):
         source = os.path.join(template_path, self._source)
-        LOGGER.debug('running CallCopy("%s")', source )
+        LOGGER.debug('running CallCopy("%s")', source)
         basepathlen = len(source) + 1
         for root, dirs, files in os.walk(source):
             for d in dirs:
                 origin = os.path.join(root, d)
-                path = os.path.join(output, origin[basepathlen:])
+                path = os.path.join(output, self._parse(origin[basepathlen:]))
                 if not os.path.exists(path):
                     LOGGER.info('Creating directory %s', path)
                     os.makedirs(path)
             for f in files:
                 origin = os.path.join(root, f)
-                path = os.path.join(output, origin[basepathlen:])
+                path = os.path.join(output, self._parse(origin[basepathlen:]))
                 with open(origin) as fd:
                     if path.endswith('.jinja'):
                         target = path[:-len('.jinja')]
                         LOGGER.info('Applying template %s to %s',
                                     origin, target)
-                        template = jinja2.Template(fd.read())
-                        content = template.render(Variables())
+                        content = self._parse(fd.read())
                     else:
                         target = path
                         LOGGER.info('Copying file %s to %s', origin, target)
@@ -82,8 +81,15 @@ class CallCopy(object):
                         'File "%s" already exists and will not be overriden.',
                         target)
                     continue
-                with open(target, 'w+') as fd:
-                    fd.write(content)
+                self._write_result(target, content, origin)
+
+    def _parse(self, template):
+        return jinja2.Template(template).render(Variables())
+
+    def _write_result(self, target, content, origin):
+        with open(target, 'w+') as fd:
+            fd.write(content)
+        os.chmod(target,  os.stat(origin).st_mode)
 
 
 class CallPrompt(object):
@@ -104,9 +110,9 @@ class CallPrompt(object):
 
 
 COMMANDS = dict(
-    run = CallRun,
-    copy = CallCopy,
-    prompt = CallPrompt,
+    run=CallRun,
+    copy=CallCopy,
+    prompt=CallPrompt,
 )
 
 
@@ -139,6 +145,7 @@ class Runner(object):
             else:
                 LOGGER.error('Unsupported command: %s', command)
 
+
 def logging_setup(verbose):
     if verbose:
         FORMAT = '%(asctime)s [%(levelname)s] %(message)s'
